aboutsummaryrefslogtreecommitdiff
path: root/src/tools/windows/converter/ms_symbol_server_converter.h
diff options
context:
space:
mode:
authormmentovai <mmentovai@4c0a9323-5329-0410-9bdc-e9ce6186880e>2007-02-14 19:51:05 +0000
committermmentovai <mmentovai@4c0a9323-5329-0410-9bdc-e9ce6186880e>2007-02-14 19:51:05 +0000
commite5dc60822e5938fea2ae892ccddb906641ba174e (patch)
treed7d4a8e94fee7bdb4eee6501221d92595ebd5f02 /src/tools/windows/converter/ms_symbol_server_converter.h
parentChange the symbol table parsing so that it will only use symbols that are fro... (diff)
downloadbreakpad-e5dc60822e5938fea2ae892ccddb906641ba174e.tar.xz
Rename Airbag to Breakpad.
git-svn-id: http://google-breakpad.googlecode.com/svn/trunk@122 4c0a9323-5329-0410-9bdc-e9ce6186880e
Diffstat (limited to 'src/tools/windows/converter/ms_symbol_server_converter.h')
-rw-r--r--src/tools/windows/converter/ms_symbol_server_converter.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/tools/windows/converter/ms_symbol_server_converter.h b/src/tools/windows/converter/ms_symbol_server_converter.h
index b675b31b..fffb7b8b 100644
--- a/src/tools/windows/converter/ms_symbol_server_converter.h
+++ b/src/tools/windows/converter/ms_symbol_server_converter.h
@@ -28,7 +28,7 @@
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// ms_symbol_server_converter.h: Obtain symbol files from a Microsoft
// symbol server, and convert them to Airbag's dumped format.
//
// At runtime, MSSymbolServerConverter and code that it calls depend on being
// able to locate suitable versions of dbghelp.dll and symsrv.dll. For best
@@ -71,7 +71,7 @@
#include <string>
#include <vector>
-namespace google_airbag {
+namespace google_breakpad {
using std::string;
using std::vector;
@@ -196,6 +196,6 @@ class MSSymbolServerConverter {
// fail_* member set, then it is authoritative.
};
-} // namespace google_airbag
+} // namespace google_breakpad
#endif // MS_SYMBOL_SERVER_CONVERTER_H__
@@ -28,7 +28,7 @@
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// ms_symbol_server_converter.h: Obtain symbol files from a Microsoft
-// symbol server, and convert them to Airbag's dumped format.
+// symbol server, and convert them to Breakpad's dumped format.
//
// At runtime, MSSymbolServerConverter and code that it calls depend on being